@@ -23,7 +23,6 @@
 #define FILEANALYZER_H
 
 #include <QList>
-#include <QMutex>
 #include <QString>
 #include <QStringList>
 
@@ -37,7 +36,6 @@
 
 #include "analyzer.h"
 
-class LogViewModel;
 class LogFileReader;
 class LogMode;
 
@@ -52,7 +50,7 @@ public:
 
     void watchLogFiles(bool enabled) override;
 
-    void setLogFiles(const QList<LogFile> &logFiles) override;
+    void setLogFiles(const QVector<LogFile> &logFiles) override;
 
 protected:
     virtual LogFileReader *createLogFileReader(const LogFile &logFile) = 0;
@@ -76,11 +74,10 @@ private:
     bool insertLine(const QString &buffer, const LogFile &originalFile, ReadingMode readingMode);
 
 private Q_SLOTS:
-    void logFileChanged(LogFileReader *logFileReader, Analyzer::ReadingMode readingMode,
-                        const QStringList &content);
+    void logFileChanged(LogFileReader *logFileReader, Analyzer::ReadingMode readingMode, const QStringList &content);
 
 protected:
-    QList<LogFileReader *> logFileReaders;
+    QList<LogFileReader *> mLogFileReaders;
 };
 
 #endif // _FILEANALYZER_H
