@@ -38,15 +38,14 @@ class LogFileReader : public QObject
 public:
     explicit LogFileReader(const LogFile &logFile);
 
-    virtual ~LogFileReader();
+    ~LogFileReader() override;
 
     virtual void watchFile(bool enable) = 0;
 
     LogFile logFile() const;
 
 Q_SIGNALS:
-    void contentChanged(LogFileReader *origin, Analyzer::ReadingMode readingMode,
-                        const QStringList &newLines);
+    void contentChanged(LogFileReader *origin, Analyzer::ReadingMode readingMode, const QStringList &newLines);
 
     void statusBarChanged(const QString &message);
     void errorOccured(const QString &title, const QString &message);
