@@ -22,11 +22,9 @@
 #ifndef LOG_MODE_ACTION_H
 #define LOG_MODE_ACTION_H
 
-#include <QObject>
-#include <QList>
 #include <QAction>
-
-class LogModeActionPrivate;
+#include <QList>
+#include <QObject>
 
 class LogModeAction : public QObject
 {
@@ -37,9 +35,9 @@ public:
 
     Q_DECLARE_FLAGS(Categories, Category)
 
-    LogModeAction();
+    explicit LogModeAction(QObject *parent = nullptr);
 
-    virtual ~LogModeAction();
+    ~LogModeAction() override;
 
     virtual QList<QAction *> innerActions() = 0;
 
@@ -47,10 +45,11 @@ public:
 
     void setCategory(Category category);
 
-    Category category();
+    Category category() const;
 
 private:
-    LogModeActionPrivate *const d;
+    LogModeAction::Category mCategory = LogModeAction::RootCategory;
+    bool mInToolBar = true;
 };
 
 #endif // _LOG_MODE_ACTION_H
