@@ -46,14 +46,13 @@ class ApacheAccessLogMode : public LogMode
     Q_OBJECT
 
 public:
-    explicit ApacheAccessLogMode(QSharedPointer<ApacheConfiguration> &apacheConfiguration,
-                                 ApacheConfigurationWidget *apacheConfigurationWidget);
+    explicit ApacheAccessLogMode(QSharedPointer<ApacheConfiguration> &apacheConfiguration, ApacheConfigurationWidget *apacheConfigurationWidget);
 
-    ~ApacheAccessLogMode();
+    ~ApacheAccessLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _APACHE_ACCESS_LOG_MODE_H
