@@ -20,9 +20,9 @@
  ***************************************************************************/
 
 #include "journaldFactory.h"
+#include "journaldConfiguration.h"
 #include "journaldLocalAnalyzer.h"
 #include "journaldLogMode.h"
-#include "journaldConfiguration.h"
 #include "logMode.h"
 #include "logging.h"
 #include "multipleActions.h"
@@ -31,18 +31,15 @@
 
 QList<LogMode *> JournaldModeFactory::createLogModes() const
 {
-    QList<LogMode *> logModes;
-    logModes.append(new JournaldLogMode());
+    const QList<LogMode *> logModes{new JournaldLogMode()};
     return logModes;
 }
 
 LogModeAction *JournaldModeFactory::createLogModeAction() const
 {
-    JournaldLogMode *logMode = dynamic_cast<JournaldLogMode *>(
-        Globals::instance().findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID)));
+    JournaldLogMode *logMode = dynamic_cast<JournaldLogMode *>(Globals::instance().findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID)));
 
-    MultipleActions *multipleActions
-        = new MultipleActions(QIcon::fromTheme(QLatin1String(JOURNALD_MODE_ICON)), i18n("Journald"), logMode);
+    auto multipleActions = new MultipleActions(QIcon::fromTheme(QLatin1String(JOURNALD_MODE_ICON)), i18n("Journald"), logMode);
 
     QIcon filterIcon = QIcon::fromTheme(QLatin1String("view-filter"));
     QIcon remoteIcon = QIcon::fromTheme(QLatin1String("preferences-system-network-sharing"));
@@ -58,11 +55,10 @@ LogModeAction *JournaldModeFactory::createLogModeAction() const
 
     actionData.analyzerOptions = QVariant::fromValue(analyzerOptions);
 
-    KActionMenu *actionMenu = new KActionMenu(QIcon::fromTheme(QLatin1String("drive-harddisk")),
-                                              i18n("Local journal"), multipleActions);
+    auto actionMenu = new KActionMenu(QIcon::fromTheme(QLatin1String("drive-harddisk")), i18n("Local journal"), multipleActions);
 
     // Add "All messages" action.
-    QAction *action = new QAction(filterIcon, i18n("All messages"), actionMenu);
+    auto action = new QAction(filterIcon, i18n("All messages"), actionMenu);
     action->setData(QVariant::fromValue(actionData));
     actionMenu->addAction(action);
     multipleActions->addInnerAction(action, false, true);
@@ -73,8 +69,8 @@ LogModeAction *JournaldModeFactory::createLogModeAction() const
     actionMenu->addAction(action);
 
     // Add filtering by systemd unit.
-    KActionMenu *filterActionMenu = new KActionMenu(filterIcon, i18n("Filter by systemd unit"), actionMenu);
-    QStringList units = JournaldLocalAnalyzer::unitsStatic();
+    auto filterActionMenu = new KActionMenu(filterIcon, i18n("Filter by systemd unit"), actionMenu);
+    const QStringList units = JournaldLocalAnalyzer::unitsStatic();
     for (const QString &unit : units) {
         action = new QAction(unit, filterActionMenu);
 
@@ -112,7 +108,7 @@ LogModeAction *JournaldModeFactory::createLogModeAction() const
     multipleActions->addInnerAction(action, true, false);
 
     // Create remote journal submenus.
-    JournaldConfiguration *configuration = logMode->logModeConfiguration<JournaldConfiguration *>();
+    auto *configuration = logMode->logModeConfiguration<JournaldConfiguration *>();
     auto remoteJournals = configuration->remoteJournals();
     for (const auto &addressInfo : remoteJournals) {
         QString menuText = QStringLiteral("%1:%2").arg(addressInfo.address).arg(addressInfo.port);
@@ -133,26 +129,24 @@ LogModeAction *JournaldModeFactory::createLogModeAction() const
         // Add filtering by systemd unit.
         JournalFilters filters = logMode->filters(addressInfo);
         if (!filters.systemdUnits.isEmpty()) {
-            KActionMenu *filterActionMenu
-                = new KActionMenu(filterIcon, i18n("Filter by systemd unit"), actionMenu);
+            auto filterActionSystemdMenu = new KActionMenu(filterIcon, i18n("Filter by systemd unit"), actionMenu);
 
             for (const QString &unit : filters.systemdUnits) {
-                action = new QAction(unit, filterActionMenu);
+                action = new QAction(unit, filterActionSystemdMenu);
 
                 analyzerOptions.filter = QStringLiteral("_SYSTEMD_UNIT=%1").arg(unit);
                 actionData.analyzerOptions = QVariant::fromValue(analyzerOptions);
                 action->setData(QVariant::fromValue(actionData));
 
-                filterActionMenu->addAction(action);
+                filterActionSystemdMenu->addAction(action);
                 multipleActions->addInnerAction(action, false, true);
             }
-            actionMenu->addAction(filterActionMenu);
+            actionMenu->addAction(filterActionSystemdMenu);
         }
 
         // Add filtering by syslog identifier.
         if (!filters.syslogIdentifiers.isEmpty()) {
-            KActionMenu *filterActionMenu
-                = new KActionMenu(filterIcon, i18n("Filter by syslog identifier"), actionMenu);
+            auto filterActionMenu = new KActionMenu(filterIcon, i18n("Filter by syslog identifier"), actionMenu);
 
             for (const QString &id : filters.syslogIdentifiers) {
                 action = new QAction(id, filterActionMenu);
